# Patches

[![Documentation Status](https://readthedocs.org/projects/binary-patches/badge/?version=main)](https://binary-patches.readthedocs.io/en/main/?badge=main)

## Documentation

Documentation can be found [here](https://binary-patches.readthedocs.io).

## Installation

You can install this package by cloning it and running `poetry install`.

Eventually, it'll be on pypi, but I need to stabilize the submodule build and such...